View source: R/rxp_chronicler.R
| rxp_check_chronicles | R Documentation |
Scans all derivation outputs for chronicle objects and reports their status: success (Just, no warnings), warning (Just with warnings), or nothing (failed computation). Only active when chronicler is installed.
rxp_check_chronicles(project_path = ".", which_log = NULL)
project_path |
Character, defaults to ".". Path to the root directory of the project. |
which_log |
Character, defaults to NULL. If NULL the most recent build log is used. If a string is provided, it's used as a regular expression to match against available log files. |
This function is useful when using the {chronicler} package in your
rixpress pipeline. Because chronicler catches errors and warnings,
returning Nothing values instead of failing, Nix builds will always
succeed. This function helps identify derivations that contain failed
computations.
The function displays one of three symbols for each chronicle:
checkmark Success: Just value, no warnings or errors
warning sign Warning: Just value, but warnings were captured
X mark Nothing: Failed computation, errors captured
A data frame with columns: derivation, chronicle_state, num_operations, num_failed, failed_functions, messages. Returns NULL invisibly if chronicler is not installed or no chronicle objects are found.
Other utilities:
print.rxp_derivation(),
rxp_copy(),
rxp_gc(),
rxp_init(),
rxp_inspect(),
rxp_list_logs(),
rxp_load(),
rxp_read(),
rxp_trace()
## Not run:
# After building a pipeline with chronicler functions
rxp_check_chronicles()
# Check a specific build log
rxp_check_chronicles(which_log = "20250131")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.