rxp_dag_for_ci: Export DAG of Pipeline and Prepare It for Rendering on CI

View source: R/plot_dag.R

rxp_dag_for_ciR Documentation

Export DAG of Pipeline and Prepare It for Rendering on CI

Description

This function generates a DOT file representation of the pipeline DAG, suitable for visualization, potentially on CI platforms. It is called by rxp_ga().

Usage

rxp_dag_for_ci(
  nodes_and_edges = get_nodes_edges(),
  output_file = "_rixpress/dag.dot"
)

Arguments

nodes_and_edges

List, output of get_nodes_edges(). Defaults to calling get_nodes_edges().

output_file

Character, the path where the DOT file should be saved. Defaults to "_rixpress/dag.dot". The directory will be created if it doesn't exist.

Value

Nothing, writes the DOT file to the specified output_file.

See Also

Other ci utilities: rxp_ga(), rxp_write_dag()

Examples

## Not run: 
  # Generate the default _rixpress/dag.dot
  rxp_dag_for_ci()


## End(Not run)

rixpress documentation built on Feb. 19, 2026, 9:06 a.m.