rxp_ga: Run a Pipeline on GitHub Actions

View source: R/rxp_ga.R

rxp_gaR Documentation

Run a Pipeline on GitHub Actions

Description

Run a Pipeline on GitHub Actions

Usage

rxp_ga()

Details

This function puts a .yaml file inside the ⁠.github/workflows/⁠ folder on the root of your project. This workflow file expects both scripts generated by rxp_init(), gen-env.R and gen-pipeline.R to be present. If that's not the case, edit the .yaml file accordingly. Build artifacts are archived and restored automatically between runs. Make sure to give read and write permissions to the GitHub Actions bot.

Value

Nothing, copies file to a directory.

See Also

Other ci utilities: rxp_dag_for_ci(), rxp_write_dag()

Examples

## Not run: 
  rxp_ga()

## End(Not run)

rixpress documentation built on Feb. 19, 2026, 9:06 a.m.