rxp_import_artifacts: Import Nix Store Paths from an Archive

View source: R/rxp_make.R

rxp_import_artifactsR Documentation

Import Nix Store Paths from an Archive

Description

Imports the store paths contained in an archive file into the local Nix store. Useful for transferring built outputs between machines.

Usage

rxp_import_artifacts(archive_file = "_rixpress/pipeline_outputs.nar")

Arguments

archive_file

Character, path to the archive, defaults to "_rixpress/pipeline-outputs.nar"

Value

Nothing, imports the archive contents into the local Nix store.

See Also

Other archive caching functions: rxp_export_artifacts()

Examples

## Not run: 
  # Import from the default archive location
  rxp_import_artifacts()

  # Import from a custom archive file
  rxp_import_artifacts("path/to/my_archive.nar")

## End(Not run)

rixpress documentation built on Feb. 19, 2026, 9:06 a.m.