rxp_list_logs: List All Available Build Logs

View source: R/rxp_inspect.R

rxp_list_logsR Documentation

List All Available Build Logs

Description

Returns a data frame with information about all build logs in the project's _rixpress directory.

Usage

rxp_list_logs(project_path = ".")

Arguments

project_path

Character, defaults to ".". Path to the root directory of the project.

Value

A data frame with log filenames, modification times, and file sizes.

See Also

Other utilities: print.rxp_derivation(), rxp_check_chronicles(), rxp_copy(), rxp_gc(), rxp_init(), rxp_inspect(), rxp_load(), rxp_read(), rxp_trace()

Examples

## Not run: 
  # List all build logs in the current project
  logs <- rxp_list_logs()

  # List logs from a specific project directory
  logs <- rxp_list_logs("path/to/project")

## End(Not run)

rixpress documentation built on Feb. 19, 2026, 9:06 a.m.