| rxp_py2r | R Documentation |
Transfer Python Object into an R Session
rxp_py2r(name, expr, nix_env = "default.nix", project_path = ".")
name |
Symbol, name of the derivation. |
expr |
Symbol, Python object to be loaded into R. |
nix_env |
Character, path to the Nix environment file, default is "default.nix". |
project_path |
Character, path to the project root, default is ".". |
rxp_py2r(my_obj, my_python_object) loads a serialized Python
object and saves it as an RDS file using reticulate::py_load_object().
An object of class rxp_derivation.
Other interop functions:
rxp_r2py()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.