rxp_r2py: Transfer R Object into a Python Session

View source: R/rxp_io.R

rxp_r2pyR Documentation

Transfer R Object into a Python Session

Description

Transfer R Object into a Python Session

Usage

rxp_r2py(name, expr, nix_env = "default.nix", project_path = ".")

Arguments

name

Symbol, name of the derivation.

expr

Symbol, R object to be saved into a Python pickle.

nix_env

Character, path to the Nix environment file, default is "default.nix".

project_path

Character, path to the project root, default is ".".

Details

rxp_r2py(my_obj, my_r_object) saves an R object to a Python pickle using reticulate::py_save_object().

Value

An object of class rxp_derivation.

See Also

Other interop functions: rxp_py2r()


rixpress documentation built on Feb. 19, 2026, 9:06 a.m.