| rxp_import_artifacts | R Documentation |
Imports the store paths contained in an archive file into the local Nix store. Useful for transferring built outputs between machines.
rxp_import_artifacts(archive_file = "_rixpress/pipeline_outputs.nar")
archive_file |
Character, path to the archive, defaults to "_rixpress/pipeline-outputs.nar" |
Nothing, imports the archive contents into the local Nix store.
Other archive caching functions:
rxp_export_artifacts()
## Not run:
# Import from the default archive location
rxp_import_artifacts()
# Import from a custom archive file
rxp_import_artifacts("path/to/my_archive.nar")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.