| rxp_init | R Documentation |
Generates gen-env.R and gen-pipeline.R scripts in the specified project
directory, after asking the user for confirmation. If the user declines, no
changes are made.
rxp_init(project_path = ".", skip_prompt = FALSE)
project_path |
Character string specifying the project's path. |
skip_prompt |
Logical. If TRUE, skips all confirmation prompts and proceeds with initialization, useful on continuous integration. Defaults to FALSE. |
Creates (overwriting if they already exist):
gen-env.R: Script to define an execution environment with {rix}.
gen-pipeline.R: Defines a data pipeline with {rixpress}.
Logical. Returns TRUE if initialization was successful, FALSE if the operation was cancelled by the user.
Other utilities:
print.rxp_derivation(),
rxp_check_chronicles(),
rxp_copy(),
rxp_gc(),
rxp_inspect(),
rxp_list_logs(),
rxp_load(),
rxp_read(),
rxp_trace()
# Default usage (will prompt before any action)
## Not run:
rxp_init()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.