| rxp_inspect | R Documentation |
Returns a data frame with four columns:
- derivation: the name of the derivation
- build_success: whether the build was successful or not
- path: the path of this derivation in the Nix store
- output: the output, if this derivation was built successfully.
Empty outputs mean that this derivation was not built
successfully. Several outputs for a single derivation
are possible.
In the derivation column you will find an object called all-derivations.
This object is generated automatically for internal purposes, and you can
safely ignore it.
rxp_inspect(project_path = ".", which_log = NULL)
project_path |
Character, defaults to ".". Path to the root directory of the project. |
which_log |
Character, defaults to NULL. If NULL the most recent build log is used. If a string is provided, it's used as a regular expression to match against available log files. |
A data frame with derivation names, if their build was successful, their paths in the /nix/store, and their build outputs.
Other utilities:
print.rxp_derivation(),
rxp_check_chronicles(),
rxp_copy(),
rxp_gc(),
rxp_init(),
rxp_list_logs(),
rxp_load(),
rxp_read(),
rxp_trace()
## Not run:
# Inspect the most recent build
build_results <- rxp_inspect()
# Inspect a specific build log
build_results <- rxp_inspect(which_log = "20250510")
# Check which derivations failed
failed <- subset(build_results, !build_success)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.