| rxp_list_logs | R Documentation |
Returns a data frame with information about all build logs in the project's _rixpress directory.
rxp_list_logs(project_path = ".")
project_path |
Character, defaults to ".". Path to the root directory of the project. |
A data frame with log filenames, modification times, and file sizes.
Other utilities:
print.rxp_derivation(),
rxp_check_chronicles(),
rxp_copy(),
rxp_gc(),
rxp_init(),
rxp_inspect(),
rxp_load(),
rxp_read(),
rxp_trace()
## Not run:
# List all build logs in the current project
logs <- rxp_list_logs()
# List logs from a specific project directory
logs <- rxp_list_logs("path/to/project")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.