View source: R/rxp_read_load.R
| rxp_load | R Documentation |
Loads the output of derivations in the parent frame of the current session, returns a path if reading directly is not possible.
rxp_load(derivation_name, which_log = NULL, project_path = ".")
derivation_name |
Character, the name of the derivation. |
which_log |
Character, defaults to NULL. If NULL the most recent build log is used. If a string is provided, it's used as a regular expression to match against available log files. |
project_path |
Character, defaults to ".". Path to the root directory of the project. |
When derivation_name points to a single R object, it gets loaded
in the current session using assign(..., envir = parent.frame()), which
corresponds to the global environment in a regular interactive session. If
you're trying to load a Python object and {reticulate} is available,
reticulate::py_load_object() is used and then the object gets loaded into
the global environment. In case the derivation is pointing to several
outputs (which can happen when building a Quarto document for example) or
loading fails, the path to the object is returned instead.
Nothing, this function has the side effect of loading objects into the parent frame.
Other utilities:
print.rxp_derivation(),
rxp_check_chronicles(),
rxp_copy(),
rxp_gc(),
rxp_init(),
rxp_inspect(),
rxp_list_logs(),
rxp_read(),
rxp_trace()
## Not run:
# Load an R object
rxp_load("mtcars")
# Load a Python object
rxp_load("my_python_model")
# Load from a specific build log
rxp_load("mtcars", which_log = "2025-05-10")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.