| rxp_make | R Documentation |
Runs nix-build with a quiet flag, outputting to _rixpress/result.
rxp_make(verbose = 0L, max_jobs = 1, cores = 1)
verbose |
Integer, defaults to 0L. Verbosity level: 0 = show progress indicators only, 1+ = show nix output with increasing verbosity. 0: "Progress only", 1: "Informational", 2: "Talkative", 3: "Chatty", 4: "Debug", 5: "Vomit". Values higher than 5 are capped to 5. Each level adds one –verbose flag to nix-store command. |
max_jobs |
Integer, number of derivations to be built in parallel. |
cores |
Integer, number of cores a derivation can use during build. |
When the {chronicler} package is available, rxp_make() automatically
calls rxp_check_chronicles() after a successful build to check for
Nothing values in chronicle objects. This helps detect silent failures
in pipelines that use chronicler's record() decorated functions.
See vignette("chronicler") for more details.
A character vector of paths to the built outputs.
Other pipeline functions:
rxp_pipeline(),
rxp_populate()
## Not run:
# Build the pipeline with progress indicators (default)
rxp_make()
# Build with verbose output and parallel execution
rxp_make(verbose = 2, max_jobs = 4, cores = 2)
# Maximum verbosity
rxp_make(verbose = 3)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.