| rxp_r2py | R Documentation |
Transfer R Object into a Python Session
rxp_r2py(name, expr, nix_env = "default.nix", project_path = ".")
name |
Symbol, name of the derivation. |
expr |
Symbol, R object to be saved into a Python pickle. |
nix_env |
Character, path to the Nix environment file, default is "default.nix". |
project_path |
Character, path to the project root, default is ".". |
rxp_r2py(my_obj, my_r_object) saves an R object to a Python pickle
using reticulate::py_save_object().
An object of class rxp_derivation.
Other interop functions:
rxp_py2r()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.