| rxp_visnetwork | R Documentation |
{visNetwork}Uses {visNetwork} to generate the plot. {visNetwork} is a
soft dependency of {rixpress} so you need to install it to use this
function. When derivations are organized into pipelines using
rxp_pipeline(), nodes use a dual-encoding approach: the interior fill
shows the derivation type (R, Python, etc.) while the border shows
the pipeline group colour.
rxp_visnetwork(
nodes_and_edges = get_nodes_edges(),
color_by = c("pipeline", "type"),
colour_by = NULL
)
nodes_and_edges |
List, output of |
color_by |
Character, either "pipeline" (default) or "type". When "pipeline", nodes show type as fill colour and pipeline as border. When "type", nodes are colored by their derivation type (rxp_r, rxp_py, etc.). |
colour_by |
Character, alias for |
Nothing, this function opens a new tab in your browser with
the DAG generated using {visNetwork}.
Other visualisation functions:
rxp_ggdag()
## Not run:
rxp_visnetwork()
rxp_visnetwork(colour_by = "type") # Color by derivation type instead
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.